View Source Membrane.Matroska.Muxer (Membrane Matroska plugin v0.1.2)
Filter element for muxing Matroska files.
It accepts an arbitrary number of Opus, VP8, VP9 or H264 streams and outputs a bytestream in Matroska format containing those streams.
Muxer guidelines https://www.matroskaproject.org/docs/container/
element-options
Element options
Passed via struct Membrane.Matroska.Muxer.t/0
titleString.t()Default value:
"Membrane Matroska file"
Title to be used in theSegment/Info/Titleelementdatenil | DateTime.t()Default value:
nil
Datetime which will be store in theSegment/Info/DateUTCelement.Default value is the time of initialization of this element.
pads
Pads
input
:input
| Availability | :on_request |
| Caps | Membrane.Opus, restrictions:self_delimiting?: false,channels: one_of([1, 2]),Membrane.RemoteStream, restrictions:content_format: one_of([Membrane.VP8, Membrane.VP9]),type: :packetized,Membrane.MP4.Payload |
| Demand mode | :manual |
| Demand unit | :buffers |
| Direction | :input |
| Mode | :pull |
| Name | :input |
output
:output
| Availability | :always |
| Caps | Membrane.RemoteStream, restrictions:content_format: Membrane.Matroska |
| Demand mode | :manual |
| Demand unit | :buffers |
| Direction | :output |
| Mode | :pull |
| Name | :output |
Link to this section Summary
Types
Struct containing options for Membrane.Matroska.Muxer
Functions
Returns pads descriptions for Membrane.Matroska.Muxer
Returns description of options available for this module
Link to this section Types
@type t() :: %Membrane.Matroska.Muxer{date: nil | DateTime.t(), title: String.t()}
Struct containing options for Membrane.Matroska.Muxer
Link to this section Functions
@spec membrane_pads() :: [{Membrane.Pad.name_t(), Membrane.Pad.description_t()}]
Returns pads descriptions for Membrane.Matroska.Muxer
@spec options() :: keyword()
Returns description of options available for this module